@@ -1,30 +1,17 @@
 /*
- *  Copyright (C) 2017 Marco Martin <mart@kde.org>
- *  Copyright (c) 2014 Vishesh Handa <me@vhanda.in>
+ *  SPDX-FileCopyrightText: 2017 Marco Martin <mart@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #ifndef _KCM_PLYMOUTH_H
 #define _KCM_PLYMOUTH_H
 
+#include <KNewStuff3/KNSCore/EntryWrapper>
 #include <QDir>
 
-#include <KNewStuff3/KNS3/DownloadDialog>
-
 #include <KQuickAddons/ConfigModule>
 
 class QQuickItem;
@@ -59,7 +46,7 @@ public:
     void setBusy(const bool &busy);
 
     Q_INVOKABLE void reloadModel();
-    Q_INVOKABLE void getNewStuff(QQuickItem *ctx);
+    Q_INVOKABLE void onChangedEntriesChanged(const QQmlListReference &changedEntries);
     Q_INVOKABLE void uninstall(const QString &plugin);
 
 public Q_SLOTS:
@@ -80,7 +67,6 @@ private:
     QStandardItemModel *m_model;
     QString m_selectedPlugin;
     bool m_busy = false;
-    QPointer<KNS3::DownloadDialog> m_newStuffDialog;
 };
 
 #endif
